
# Slot: object


the more general taxon

URI: [biolink:organism_taxon_to_organism_taxon_specialization_object](https://w3id.org/biolink/vocab/organism_taxon_to_organism_taxon_specialization_object)


## Domain and Range

[OrganismTaxonToOrganismTaxonSpecialization](OrganismTaxonToOrganismTaxonSpecialization.md) &#8594;  <sub>1..1</sub> [OrganismTaxon](OrganismTaxon.md)

## Parents

 *  is_a: [organism taxon to organism taxon association➞object](organism_taxon_to_organism_taxon_association_object.md)

## Children


## Used by

 * [OrganismTaxonToOrganismTaxonSpecialization](OrganismTaxonToOrganismTaxonSpecialization.md)
